@@ -2,47 +2,43 @@
 sentry.coreapi
 ~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 # TODO: We should make the API a class, and UDP/HTTP just inherit from it
 #       This will make it so we can more easily control logging with various
 #       metadata (rather than generic log messages which aren't useful).
+from __future__ import absolute_import, print_function
 
-from datetime import datetime, timedelta
 import base64
 import logging
 import uuid
 import zlib
+from gzip import GzipFile
 
-from django.conf import settings
+from datetime import datetime, timedelta
 from django.utils.encoding import smart_str
 
-from sentry.app import env
+import six
+
+from sentry.app import cache, env
 from sentry.constants import (
-    DEFAULT_LOG_LEVEL, LOG_LEVELS, MAX_CULPRIT_LENGTH, MAX_TAG_VALUE_LENGTH,
+    DEFAULT_LOG_LEVEL, LOG_LEVELS, MAX_TAG_VALUE_LENGTH,
     MAX_TAG_KEY_LENGTH)
 from sentry.exceptions import InvalidTimestamp
+from sentry.interfaces.base import get_interface
 from sentry.models import Project, ProjectKey
 from sentry.tasks.store import preprocess_event
 from sentry.utils import is_float, json
 from sentry.utils.auth import parse_auth_header
-from sentry.utils.imports import import_string
-from sentry.utils.strings import decompress, truncatechars
+from sentry.utils.compat import StringIO
+from sentry.utils.strings import decompress
 
 
-logger = logging.getLogger('sentry.coreapi.errors')
+logger = logging.getLogger('sentry.coreapi')
 
 LOG_LEVEL_REVERSE_MAP = dict((v, k) for k, v in LOG_LEVELS.iteritems())
 
-INTERFACE_ALIASES = {
-    'exception': 'sentry.interfaces.Exception',
-    'request': 'sentry.interfaces.Http',
-    'user': 'sentry.interfaces.User',
-    'stacktrace': 'sentry.interfaces.Stacktrace',
-    'template': 'sentry.interfaces.Template',
-}
-
 RESERVED_FIELDS = (
     'project',
     'event_id',
@@ -59,6 +55,7 @@ RESERVED_FIELDS = (
     'modules',
     'tags',
     'platform',
+    'release',
 )
 
 
@@ -91,17 +88,8 @@ class APIRateLimited(APIError):
     http_status = 429
     msg = 'Creation of this event was denied due to rate limiting.'
 
-
-def get_interface(name):
-    if name not in settings.SENTRY_ALLOWED_INTERFACES:
-        raise ValueError
-
-    try:
-        interface = import_string(name)
-    except Exception:
-        raise ValueError('Unable to load interface: %s' % (name,))
-
-    return interface
+    def __init__(self, retry_after=None):
+        self.retry_after = retry_after
 
 
 def client_metadata(client=None, project=None, exception=None, tags=None, extra=None):
@@ -119,12 +107,15 @@ def client_metadata(client=None, project=None, exception=None, tags=None, extra=
         if project.team:
             extra['team_slug'] = project.team.slug
             extra['team_id'] = project.team.id
+        if project.organization:
+            extra['organization_slug'] = project.organization.slug
+            extra['organization_id'] = project.organization.id
 
     tags['client'] = client
     if exception:
         tags['exc_type'] = type(exception).__name__
-    if project and project.team:
-        tags['project'] = '%s/%s' % (project.team.slug, project.slug)
+    if project and project.organization:
+        tags['project'] = '%s/%s' % (project.organization.slug, project.slug)
 
     result = {'extra': extra}
     if exception:
@@ -157,18 +148,48 @@ def project_from_auth_vars(auth_vars):
     if pk.secret_key != auth_vars.get('sentry_secret', pk.secret_key):
         raise APIForbidden('Invalid api key')
 
+    if not pk.roles.store:
+        raise APIForbidden('Key does not allow event storage access')
+
     project = Project.objects.get_from_cache(pk=pk.project_id)
 
     return project, pk.user
 
 
+def decompress_deflate(encoded_data):
+    try:
+        return zlib.decompress(encoded_data)
+    except Exception as e:
+        # This error should be caught as it suggests that there's a
+        # bug somewhere in the client's code.
+        logger.info(e, **client_metadata(exception=e))
+        raise APIForbidden('Bad data decoding request (%s, %s)' % (
+            e.__class__.__name__, e))
+
+
+def decompress_gzip(encoded_data):
+    try:
+        fp = StringIO(encoded_data)
+        try:
+            f = GzipFile(fileobj=fp)
+            return f.read()
+        finally:
+            f.close()
+    except Exception as e:
+        # This error should be caught as it suggests that there's a
+        # bug somewhere in the client's code.
+        logger.info(e, **client_metadata(exception=e))
+        raise APIForbidden('Bad data decoding request (%s, %s)' % (
+            e.__class__.__name__, e))
+
+
 def decode_and_decompress_data(encoded_data):
     try:
         try:
             return decompress(encoded_data)
         except zlib.error:
             return base64.b64decode(encoded_data)
-    except Exception, e:
+    except Exception as e:
         # This error should be caught as it suggests that there's a
         # bug somewhere in the client's code.
         logger.info(e, **client_metadata(exception=e))
@@ -179,7 +200,7 @@ def decode_and_decompress_data(encoded_data):
 def safely_load_json_string(json_string):
     try:
         obj = json.loads(json_string)
-    except Exception, e:
+    except Exception as e:
         # This error should be caught as it suggests that there's a
         # bug somewhere in the client's code.
         logger.info(e, **client_metadata(exception=e))
@@ -190,24 +211,11 @@ def safely_load_json_string(json_string):
     return dict((smart_str(k), v) for k, v in obj.iteritems())
 
 
-def ensure_valid_project_id(desired_project, data, client=None):
-    # Confirm they're using either the master key, or their specified project
-    # matches with the signed project.
-    if desired_project and data.get('project'):
-        if str(data.get('project')) not in [str(desired_project.id), desired_project.slug]:
-            logger.info(
-                'Project ID mismatch: %s != %s', desired_project.id, desired_project.slug,
-                **client_metadata(client))
-            raise APIForbidden('Invalid credentials')
-        data['project'] = desired_project.id
-    elif not desired_project:
-        data['project'] = 1
-    elif not data.get('project'):
-        data['project'] = desired_project.id
-
-
-def process_data_timestamp(data):
-    if is_float(data['timestamp']):
+def process_data_timestamp(data, current_datetime=None):
+    if not data['timestamp']:
+        del data['timestamp']
+        return data
+    elif is_float(data['timestamp']):
         try:
             data['timestamp'] = datetime.fromtimestamp(float(data['timestamp']))
         except Exception:
@@ -225,34 +233,37 @@ def process_data_timestamp(data):
         except Exception:
             raise InvalidTimestamp('Invalid value for timestamp: %r' % data['timestamp'])
 
-    if data['timestamp'] > datetime.now() + timedelta(minutes=1):
+    if current_datetime is None:
+        current_datetime = datetime.now()
+
+    if data['timestamp'] > current_datetime + timedelta(minutes=1):
         raise InvalidTimestamp('Invalid value for timestamp (in future): %r' % data['timestamp'])
 
+    if data['timestamp'] < current_datetime - timedelta(days=30):
+        raise InvalidTimestamp('Invalid value for timestamp (too old): %r' % data['timestamp'])
+
+    data['timestamp'] = float(data['timestamp'].strftime('%s'))
+
     return data
 
 
 def validate_data(project, data, client=None):
-    ensure_valid_project_id(project, data, client=client)
+    # TODO(dcramer): move project out of the data packet
+    data['project'] = project.id
 
     if not data.get('message'):
         data['message'] = '<no message value>'
-    elif not isinstance(data['message'], basestring):
+    elif not isinstance(data['message'], six.string_types):
         raise APIError('Invalid value for message')
-    elif len(data['message']) > settings.SENTRY_MAX_MESSAGE_LENGTH:
-        logger.info(
-            'Truncated value for message due to length (%d chars)',
-            len(data['message']), **client_metadata(client, project))
-        data['message'] = truncatechars(
-            data['message'], settings.SENTRY_MAX_MESSAGE_LENGTH)
 
-    if data.get('culprit') and len(data['culprit']) > MAX_CULPRIT_LENGTH:
-        logger.info(
-            'Truncated value for culprit due to length (%d chars)',
-            len(data['culprit']), **client_metadata(client, project))
-        data['culprit'] = truncatechars(data['culprit'], MAX_CULPRIT_LENGTH)
+    if data.get('culprit'):
+        if not isinstance(data['culprit'], six.string_types):
+            raise APIError('Invalid value for culprit')
 
     if not data.get('event_id'):
         data['event_id'] = uuid.uuid4().hex
+    elif not isinstance(data['event_id'], six.string_types):
+        raise APIError('Invalid value for event_id')
     if len(data['event_id']) > 32:
         logger.info(
             'Discarded value for event_id due to length (%d chars)',
@@ -262,7 +273,7 @@ def validate_data(project, data, client=None):
     if 'timestamp' in data:
         try:
             process_data_timestamp(data)
-        except InvalidTimestamp, e:
+        except InvalidTimestamp as e:
             # Log the error, remove the timestamp, and continue
             logger.info(
                 'Discarded invalid value for timestamp: %r', data['timestamp'],
@@ -301,17 +312,17 @@ def validate_data(project, data, client=None):
                             pair, **client_metadata(client, project))
                 continue
 
-            if not isinstance(k, basestring):
+            if not isinstance(k, six.string_types):
                 try:
-                    k = unicode(k)
+                    k = six.text_type(k)
                 except Exception:
                     logger.info('Discarded invalid tag key: %r',
                                 type(k), **client_metadata(client, project))
                     continue
 
-            if not isinstance(v, basestring):
+            if not isinstance(v, six.string_types):
                 try:
-                    v = unicode(v)
+                    v = six.text_type(v)
                 except Exception:
                     logger.info('Discarded invalid tag value: %s=%r',
                                 k, type(v), **client_metadata(client, project))
@@ -327,42 +338,37 @@ def validate_data(project, data, client=None):
         if k in RESERVED_FIELDS:
             continue
 
-        if not data[k]:
+        value = data.pop(k)
+
+        if not value:
             logger.info(
                 'Ignored empty interface value: %s', k,
                 **client_metadata(client, project))
-            del data[k]
             continue
 
-        import_path = INTERFACE_ALIASES.get(k, k)
-
-        if '.' not in import_path:
+        try:
+            interface = get_interface(k)
+        except ValueError:
             logger.info(
                 'Ignored unknown attribute: %s', k,
                 **client_metadata(client, project))
-            del data[k]
             continue
 
-        try:
-            interface = get_interface(import_path)
-        except ValueError:
-            logger.info(
-                'Invalid unknown attribute: %s', k,
-                **client_metadata(client, project))
-            del data[k]
-            continue
-
-        value = data.pop(k)
-        try:
-            # HACK: exception allows you to pass the value as a list
-            # so let's try to actually support that
-            if isinstance(value, dict):
-                inst = interface(**value)
+        if type(value) != dict:
+            # HACK(dcramer): the exception interface supports a list as the
+            # value. We should change this in a new protocol version.
+            if type(value) in (list, tuple):
+                value = {'values': value}
             else:
-                inst = interface(value)
-            inst.validate()
-            data[import_path] = inst.serialize()
-        except Exception, e:
+                logger.info(
+                    'Invalid parameters for value: %s', k,
+                    type(value), **client_metadata(client, project))
+                continue
+
+        try:
+            inst = interface.to_python(value)
+            data[inst.get_path()] = inst.to_json()
+        except Exception as e:
             if isinstance(e, AssertionError):
                 log = logger.info
             else:
@@ -371,11 +377,11 @@ def validate_data(project, data, client=None):
                 **client_metadata(client, project, exception=e, extra={'value': value}))
 
     level = data.get('level') or DEFAULT_LOG_LEVEL
-    if isinstance(level, basestring) and not level.isdigit():
+    if isinstance(level, six.string_types) and not level.isdigit():
         # assume it's something like 'warning'
         try:
             data['level'] = LOG_LEVEL_REVERSE_MAP[level]
-        except KeyError, e:
+        except KeyError as e:
             logger.info(
                 'Discarded invalid logger value: %s', level,
                 **client_metadata(client, project, exception=e))
@@ -396,4 +402,6 @@ def ensure_has_ip(data, ip_address):
 
 
 def insert_data_to_database(data):
-    preprocess_event.delay(data=data)
+    cache_key = 'e:{0}'.format(data['event_id'])
+    cache.set(cache_key, data, timeout=3600)
+    preprocess_event.delay(cache_key=cache_key)
