@@ -1,14 +1,14 @@
 """
-sentry.db.query
-~~~~~~~~~~~~~~~
+sentry.db.models.query
+~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
 from __future__ import absolute_import
 
-from django.db import router, transaction, IntegrityError
+from django.db import IntegrityError, router, transaction
 from django.db.models.expressions import ExpressionNode
 from django.db.models.signals import post_save
 
@@ -36,9 +36,9 @@ def update(self, using=None, **kwargs):
         setattr(self, k, v)
     if affected == 1:
         post_save.send(sender=self.__class__, instance=self, created=False)
-        return True
+        return affected
     elif affected == 0:
-        return False
+        return affected
     elif affected < 0:
         raise ValueError("Somehow we have updated a negative amount of rows, you seem to have a problem with your db backend.")
     else:
@@ -77,9 +77,9 @@ def create_or_update(model, using=None, **kwargs):
         else:
             create_kwargs[k] = v
     try:
-        return objects.create(**create_kwargs), True
+        with transaction.atomic():
+            return objects.create(**create_kwargs), True
     except IntegrityError:
-        transaction.rollback_unless_managed(using=using)
         affected = objects.filter(**kwargs).update(**defaults)
 
     return affected, False
