@@ -2,15 +2,17 @@
 sentry.models.grouptagkey
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
 
 from django.db import models
 
 from sentry.constants import MAX_TAG_KEY_LENGTH
 from sentry.db.models import (
-    Model, BoundedPositiveIntegerField, BaseManager, sane_repr
+    Model, BoundedPositiveIntegerField, BaseManager, FlexibleForeignKey,
+    sane_repr
 )
 
 
@@ -20,8 +22,8 @@ class GroupTagKey(Model):
 
     An example key might be "url" or "server_name".
     """
-    project = models.ForeignKey('sentry.Project', null=True)
-    group = models.ForeignKey('sentry.Group')
+    project = FlexibleForeignKey('sentry.Project', null=True)
+    group = FlexibleForeignKey('sentry.Group')
     key = models.CharField(max_length=MAX_TAG_KEY_LENGTH)
     values_seen = BoundedPositiveIntegerField(default=0)
 
