@@ -2,16 +2,16 @@
 sentry.models.option
 ~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-
-from picklefield.fields import PickledObjectField
+from __future__ import absolute_import, print_function
 
 from django.db import models
+from django.utils import timezone
 
 from sentry.db.models import Model, sane_repr
-from sentry.manager import MetaManager
+from sentry.db.models.fields import UnicodePickledObjectField
 
 
 class Option(Model):
@@ -23,11 +23,8 @@ class Option(Model):
     their key. e.g. key='myplugin:optname'
     """
     key = models.CharField(max_length=64, unique=True)
-    value = PickledObjectField()
-
-    objects = MetaManager(cache_fields=[
-        'key',
-    ])
+    value = UnicodePickledObjectField()
+    last_updated = models.DateTimeField(default=timezone.now)
 
     class Meta:
         app_label = 'sentry'
