@@ -6,40 +6,38 @@ Contains views for the "Events" section of Sentry.
 
 TODO: Move all events.py views into here, and rename this file to events.
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-from __future__ import division
+from __future__ import absolute_import, division
 
 import datetime
-import logging
 import re
+import logging
 
-from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.http import HttpResponse, HttpResponseRedirect, Http404
+from django.http import (
+    HttpResponse, HttpResponsePermanentRedirect, HttpResponseRedirect, Http404
+)
 from django.shortcuts import get_object_or_404
 from django.utils import timezone
 
 from sentry import app
 from sentry.constants import (
-    SORT_OPTIONS, SEARCH_SORT_OPTIONS, SORT_CLAUSES,
-    MYSQL_SORT_CLAUSES, SQLITE_SORT_CLAUSES, MEMBER_USER,
-    SCORE_CLAUSES, MYSQL_SCORE_CLAUSES, SQLITE_SCORE_CLAUSES,
-    ORACLE_SORT_CLAUSES, ORACLE_SCORE_CLAUSES,
-    MSSQL_SORT_CLAUSES, MSSQL_SCORE_CLAUSES, DEFAULT_SORT_OPTION,
-    SEARCH_DEFAULT_SORT_OPTION, MAX_JSON_RESULTS
+    SORT_OPTIONS, MEMBER_USER, DEFAULT_SORT_OPTION, EVENTS_PER_PAGE
 )
 from sentry.db.models import create_or_update
-from sentry.filters import get_filters
 from sentry.models import (
-    Project, Group, Event, Activity, EventMapping, TagKey, GroupSeen
+    Project, Group, GroupMeta, Event, Activity, EventMapping, TagKey, GroupSeen
+)
+from sentry.permissions import (
+    can_admin_group, can_remove_group, can_create_projects
 )
-from sentry.permissions import can_admin_group, can_create_projects
 from sentry.plugins import plugins
+from sentry.search.utils import parse_query
 from sentry.utils import json
+from sentry.utils.cursors import Cursor
 from sentry.utils.dates import parse_date
-from sentry.utils.db import has_trending, get_db_engine
 from sentry.web.decorators import has_access, has_group_access, login_required
 from sentry.web.forms import NewNoteForm
 from sentry.web.helpers import render_to_response, group_is_public
@@ -49,40 +47,47 @@ event_re = re.compile(r'^(?P<event_id>[a-z0-9]{32})\$(?P<checksum>[a-z0-9]{32})$
 
 
 def _get_group_list(request, project):
-    filters = []
-    for cls in get_filters(Group, project):
-        try:
-            filters.append(cls(request, project))
-        except Exception, e:
-            logger = logging.getLogger('sentry.filters')
-            logger.exception('Error initializing filter %r: %s', cls, e)
+    query_kwargs = {
+        'project': project,
+    }
+
+    status = request.GET.get('status', '0')
+    if status:
+        query_kwargs['status'] = int(status)
 
-    event_list = Group.objects
     if request.user.is_authenticated() and request.GET.get('bookmarks'):
-        event_list = event_list.filter(
-            bookmark_set__project=project,
-            bookmark_set__user=request.user,
-        )
-    else:
-        event_list = event_list.filter(project=project)
+        query_kwargs['bookmarked_by'] = request.user
 
-    for filter_ in filters:
-        try:
-            if not filter_.is_set():
-                continue
-            event_list = filter_.get_query_set(event_list)
-        except Exception, e:
-            logger = logging.getLogger('sentry.filters')
-            logger.exception('Error processing filter %r: %s', cls, e)
+    if request.user.is_authenticated() and request.GET.get('assigned'):
+        query_kwargs['assigned_to'] = request.user
+
+    sort_by = request.GET.get('sort') or request.session.get('streamsort')
+    if sort_by is None:
+        sort_by = DEFAULT_SORT_OPTION
+
+    # Save last sort in session
+    if sort_by != request.session.get('streamsort'):
+        request.session['streamsort'] = sort_by
+
+    query_kwargs['sort_by'] = sort_by
+
+    tags = {}
+    for tag_key in TagKey.objects.all_keys(project):
+        if request.GET.get(tag_key):
+            tags[tag_key] = request.GET[tag_key]
+
+    if tags:
+        query_kwargs['tags'] = tags
+    else:
+        query_kwargs['tags'] = {}
 
     date_from = request.GET.get('df')
     time_from = request.GET.get('tf')
     date_to = request.GET.get('dt')
     time_to = request.GET.get('tt')
-    date_type = request.GET.get('date_type')
+    date_filter = request.GET.get('date_type')
 
     today = timezone.now()
-
     # date format is Y-m-d
     if any(x is not None for x in [date_from, time_from, date_to, time_to]):
         date_from, date_to = parse_date(date_from, time_from), parse_date(date_to, time_to)
@@ -90,84 +95,41 @@ def _get_group_list(request, project):
         date_from = today - datetime.timedelta(days=5)
         date_to = None
 
-    if date_type == 'first_seen':
-        if date_from:
-            event_list = event_list.filter(first_seen__gte=date_from)
-        elif date_to:
-            event_list = event_list.filter(first_seen__lte=date_to)
-    else:
-        if date_from and date_to:
-            event_list = event_list.filter(
-                groupcountbyminute__date__gte=date_from,
-                groupcountbyminute__date__lte=date_to,
-            )
-        elif date_from:
-            event_list = event_list.filter(last_seen__gte=date_from)
-        elif date_to:
-            event_list = event_list.filter(last_seen__lte=date_to)
+    query_kwargs['date_from'] = date_from
+    query_kwargs['date_to'] = date_to
+    if date_filter:
+        query_kwargs['date_filter'] = date_filter
 
-    sort = request.GET.get('sort') or request.session.get('streamsort')
-    if sort not in SORT_OPTIONS:
-        sort = DEFAULT_SORT_OPTION
+    cursor = request.GET.get('cursor')
+    if cursor:
+        try:
+            query_kwargs['cursor'] = Cursor.from_string(cursor)
+        except ValueError:
+            # XXX(dcramer): ideally we'd error, but this is an internal API so
+            # we'd rather just throw it away
+            logging.info('Throwing away invalid cursor: %s', cursor)
+    query_kwargs['limit'] = EVENTS_PER_PAGE
 
-    # Save last sort in session
-    if sort != request.session.get('streamsort'):
-        request.session['streamsort'] = sort
+    query = request.GET.get('query', '')
+    if query is not None:
+        query_result = parse_query(query, request.user)
+        # Disclaimer: the following code is disgusting
+        if query_result.get('query'):
+            query_kwargs['query'] = query_result['query']
+        if query_result.get('tags'):
+            query_kwargs['tags'].update(query_result['tags'])
 
-    if sort.startswith('accel_') and not has_trending():
-        sort = DEFAULT_SORT_OPTION
-
-    engine = get_db_engine('default')
-    if engine.startswith('sqlite'):
-        score_clause = SQLITE_SORT_CLAUSES.get(sort)
-        filter_clause = SQLITE_SCORE_CLAUSES.get(sort)
-    elif engine.startswith('mysql'):
-        score_clause = MYSQL_SORT_CLAUSES.get(sort)
-        filter_clause = MYSQL_SCORE_CLAUSES.get(sort)
-    elif engine.startswith('oracle'):
-        score_clause = ORACLE_SORT_CLAUSES.get(sort)
-        filter_clause = ORACLE_SCORE_CLAUSES.get(sort)
-    elif engine in ('django_pytds', 'sqlserver_ado', 'sql_server.pyodbc'):
-        score_clause = MSSQL_SORT_CLAUSES.get(sort)
-        filter_clause = MSSQL_SCORE_CLAUSES.get(sort)
-    else:
-        score_clause = SORT_CLAUSES.get(sort)
-        filter_clause = SCORE_CLAUSES.get(sort)
-
-    # IMPORTANT: All filters must already be applied once we reach this point
-
-    if sort == 'tottime':
-        event_list = event_list.filter(time_spent_count__gt=0)
-    elif sort == 'avgtime':
-        event_list = event_list.filter(time_spent_count__gt=0)
-    elif sort.startswith('accel_'):
-        event_list = Group.objects.get_accelerated(
-            [project.id], event_list, minutes=int(sort.split('_', 1)[1]))
-
-    if score_clause:
-        event_list = event_list.extra(
-            select={'sort_value': score_clause},
-        )
-        # HACK: don't sort by the same column twice
-        if sort == 'date':
-            event_list = event_list.order_by('-last_seen')
-        else:
-            event_list = event_list.order_by('-sort_value', '-last_seen')
-        cursor = request.GET.get('cursor', request.GET.get('c'))
-        if cursor:
-            event_list = event_list.extra(
-                where=['%s > %%s' % filter_clause],
-                params=[float(cursor)],
-            )
+    results = app.search.query(**query_kwargs)
 
     return {
-        'filters': filters,
-        'event_list': event_list,
+        'event_list': results[:EVENTS_PER_PAGE],
         'date_from': date_from,
         'date_to': date_to,
         'today': today,
-        'sort': sort,
-        'date_type': date_type
+        'sort': sort_by,
+        'date_type': date_filter,
+        'next_cursor': results.next,
+        'prev_cursor': results.prev,
     }
 
 
@@ -175,9 +137,11 @@ def render_with_group_context(group, template, context, request=None,
                               event=None, is_public=False):
     context.update({
         'team': group.project.team,
+        'organization': group.project.organization,
         'project': group.project,
         'group': group,
         'can_admin_event': can_admin_group(request.user, group),
+        'can_remove_event': can_remove_group(request.user, group),
     })
 
     if event:
@@ -222,23 +186,25 @@ def redirect_to_group(request, project_id, group_id):
 
     return HttpResponseRedirect(reverse('sentry-group', kwargs={
         'project_id': group.project.slug,
-        'team_slug': group.team.slug,
+        'organization_slug': group.project.organization.slug,
         'group_id': group.id,
     }))
 
 
 @login_required
 @has_access
-def dashboard(request, team):
+def dashboard(request, organization, team):
     project_list = list(Project.objects.filter(team=team))
 
     if not project_list and can_create_projects(request.user, team=team):
-        return HttpResponseRedirect(reverse('sentry-new-project', args=[team.slug]))
+        url = reverse('sentry-create-project', args=[team.organization.slug])
+        return HttpResponseRedirect(url + '?team=' + team.slug)
 
     for project in project_list:
         project.team = team
 
     return render_to_response('sentry/dashboard.html', {
+        'organization': team.organization,
         'team': team,
         'project_list': project_list,
     }, request)
@@ -246,7 +212,7 @@ def dashboard(request, team):
 
 @login_required
 @has_access
-def wall_display(request, team):
+def wall_display(request, organization, team):
     project_list = list(Project.objects.filter(team=team))
 
     for project in project_list:
@@ -254,131 +220,107 @@ def wall_display(request, team):
 
     return render_to_response('sentry/wall.html', {
         'team': team,
+        'organization': team.organization,
         'project_list': project_list,
     }, request)
 
 
 @login_required
 @has_access
-def search(request, team, project):
-    query = request.GET.get('q', '').strip()
-
-    if not query:
-        return HttpResponseRedirect(reverse('sentry-stream', args=[team.slug, project.slug]))
-
-    sort = request.GET.get('sort')
-    if sort not in SEARCH_SORT_OPTIONS:
-        sort = SEARCH_DEFAULT_SORT_OPTION
-    sort_label = SEARCH_SORT_OPTIONS[sort]
-
-    result = event_re.match(query)
-    if result:
-        # Forward to aggregate if it exists
-        # event_id = result.group(1)
-        checksum = result.group(2)
-        try:
-            group = Group.objects.filter(project=project, checksum=checksum)[0]
-        except IndexError:
-            return render_to_response('sentry/invalid_message_id.html', {
-                'team': team,
-                'project': project,
-            }, request)
-        else:
-            return HttpResponseRedirect(reverse('sentry-group', kwargs={
-                'project_id': group.project.slug,
-                'team_slug': group.team.slug,
-                'group_id': group.id,
-            }))
-    elif uuid_re.match(query):
+def group_list(request, organization, project):
+    query = request.GET.get('query', 'is:unresolved')
+    if query and uuid_re.match(query):
         # Forward to event if it exists
         try:
-            group_id = EventMapping.objects.get(
+            group_id = EventMapping.objects.filter(
                 project=project, event_id=query
-            ).group_id
-        except EventMapping.DoesNotExist:
-            try:
-                event = Event.objects.get(project=project, event_id=query)
-            except Event.DoesNotExist:
-                return render_to_response('sentry/invalid_message_id.html', {
-                    'team': team,
-                    'project': project,
-                }, request)
-            else:
-                return HttpResponseRedirect(reverse('sentry-group-event', kwargs={
-                    'project_id': project.slug,
-                    'team_slug': team.slug,
-                    'group_id': event.group.id,
-                    'event_id': event.id,
-                }))
+            ).values_list('group', flat=True)[0]
+        except IndexError:
+            pass
         else:
             return HttpResponseRedirect(reverse('sentry-group', kwargs={
                 'project_id': project.slug,
-                'team_slug': team.slug,
+                'organization_slug': project.organization.slug,
                 'group_id': group_id,
             }))
-    elif not settings.SENTRY_USE_SEARCH:
-        event_list = Group.objects.none()
-        # return render_to_response('sentry/invalid_message_id.html', {
-        #         'project': project,
-        #     }, request)
-    else:
-        documents = list(app.search.query(project, query, sort_by=sort))
-        groups = Group.objects.in_bulk([d.group_id for d in documents])
-
-        event_list = []
-        for doc in documents:
-            try:
-                event_list.append(groups[doc.group_id])
-            except KeyError:
-                continue
-
-    return render_to_response('sentry/search.html', {
-        'team': project.team,
-        'project': project,
-        'event_list': event_list,
-        'query': query,
-        'sort': sort,
-        'sort_label': sort_label,
-    }, request)
-
-
-@login_required
-@has_access
-def group_list(request, team, project):
-    try:
-        page = int(request.GET.get('p', 1))
-    except (TypeError, ValueError):
-        page = 1
 
     response = _get_group_list(
         request=request,
         project=project,
     )
+    if isinstance(response, HttpResponse):
+        return response
 
     # XXX: this is duplicate in _get_group_list
     sort_label = SORT_OPTIONS[response['sort']]
 
-    has_realtime = page == 1
+    has_realtime = not request.GET.get('cursor')
+
+    query_dict = request.GET.copy()
+    if 'cursor' in query_dict:
+        del query_dict['cursor']
+    cursorless_query_string = query_dict.urlencode()
+
+    GroupMeta.objects.populate_cache(response['event_list'])
 
     return render_to_response('sentry/groups/group_list.html', {
         'team': project.team,
+        'organization': organization,
         'project': project,
         'from_date': response['date_from'],
         'to_date': response['date_to'],
         'date_type': response['date_type'],
         'has_realtime': has_realtime,
         'event_list': response['event_list'],
+        'prev_cursor': response['prev_cursor'],
+        'next_cursor': response['next_cursor'],
         'today': response['today'],
         'sort': response['sort'],
+        'query': query,
+        'cursorless_query_string': cursorless_query_string,
         'sort_label': sort_label,
-        'filters': response['filters'],
         'SORT_OPTIONS': SORT_OPTIONS,
-        'HAS_TRENDING': has_trending(),
     }, request)
 
 
+def group(request, organization_slug, project_id, group_id, event_id=None):
+    # TODO(dcramer): remove in 7.1 release
+    # Handle redirects from team_slug/project_slug to org_slug/project_slug
+    try:
+        group = Group.objects.get(id=group_id)
+    except Group.DoesNotExist:
+        raise Http404
+
+    if group.project.slug != project_id:
+        raise Http404
+
+    if group.organization.slug == organization_slug:
+        return group_details(
+            request=request,
+            organization_slug=organization_slug,
+            project_id=project_id,
+            group_id=group_id,
+            event_id=event_id,
+        )
+
+    if group.team.slug == organization_slug:
+        if event_id:
+            url = reverse(
+                'sentry-group-event',
+                args=[group.organization.slug, project_id, group_id, event_id],
+            )
+        else:
+            url = reverse(
+                'sentry-group',
+                args=[group.organization.slug, project_id, group_id],
+            )
+        return HttpResponsePermanentRedirect(url)
+
+    raise Http404
+
+
 @has_group_access(allow_public=True)
-def group(request, team, project, group, event_id=None):
+def group_details(request, organization, project, group, event_id=None):
     # It's possible that a message would not be created under certain
     # circumstances (such as a post_save signal failing)
     if event_id:
@@ -387,6 +329,7 @@ def group(request, team, project, group, event_id=None):
         event = group.get_latest_event() or Event()
 
     Event.objects.bind_nodes([event], 'data')
+    GroupMeta.objects.populate_cache([group])
 
     # bind params to group in case they get hit
     event.group = group
@@ -400,14 +343,7 @@ def group(request, team, project, group, event_id=None):
     else:
         add_note_form = NewNoteForm()
 
-    activity_qs = Activity.objects.order_by('-datetime').select_related('user')
-    # if event_id:
-    #     activity_qs = activity_qs.filter(
-    #         Q(event=event) | Q(event__isnull=True),
-    #     )
-
-    if project in Project.objects.get_for_user(
-            request.user, team=team, superuser=False):
+    if project.has_access(request.user):
         # update that the user has seen this group
         create_or_update(
             GroupSeen,
@@ -419,13 +355,17 @@ def group(request, team, project, group, event_id=None):
             }
         )
 
+    activity_qs = Activity.objects.filter(
+        group=group,
+    ).order_by('-datetime').select_related('user')
+
     # filter out dupe activity items
     activity_items = set()
     activity = []
-    for item in activity_qs.filter(group=group)[:20]:
+    for item in activity_qs[:20]:
         sig = (item.event_id, item.type, item.ident, item.user_id)
         # TODO: we could just generate a signature (hash(text)) for notes
-        # so theres no special casing
+        # so there's no special casing
         if item.type == Activity.NOTE:
             activity.append(item)
         elif sig not in activity_items:
@@ -473,7 +413,7 @@ def group(request, team, project, group, event_id=None):
 
 
 @has_group_access
-def group_tag_list(request, team, project, group):
+def group_tag_list(request, organization, project, group):
     def percent(total, this):
         return int(this / total * 100)
 
@@ -493,20 +433,31 @@ def group_tag_list(request, team, project, group):
 
 
 @has_group_access
-def group_tag_details(request, team, project, group, tag_name):
+def group_tag_details(request, organization, project, group, tag_name):
+    sort = request.GET.get('sort')
+    if sort == 'date':
+        order_by = '-last_seen'
+    elif sort == 'new':
+        order_by = '-first_seen'
+    else:
+        order_by = '-times_seen'
+
     return render_with_group_context(group, 'sentry/plugins/bases/tag/index.html', {
         'title': tag_name.replace('_', ' ').title(),
         'tag_name': tag_name,
-        'unique_tags': group.get_unique_tags(tag_name),
+        'unique_tags': group.get_unique_tags(tag_name, order_by=order_by),
         'page': 'tag_details',
     }, request)
 
 
 @has_group_access
-def group_event_list(request, team, project, group):
+def group_event_list(request, organization, project, group):
     # TODO: we need the event data to bind after we limit
     event_list = group.event_set.all().order_by('-datetime')[:100]
 
+    for event in event_list:
+        event.project = project
+
     Event.objects.bind_nodes(event_list, 'data')
 
     return render_with_group_context(group, 'sentry/groups/event_list.html', {
@@ -516,26 +467,7 @@ def group_event_list(request, team, project, group):
 
 
 @has_access(MEMBER_USER)
-def group_event_list_json(request, team, project, group_id):
-    group = get_object_or_404(Group, id=group_id, project=project)
-
-    limit = request.GET.get('limit', MAX_JSON_RESULTS)
-    try:
-        limit = int(limit)
-    except ValueError:
-        return HttpResponse('non numeric limit', status=400, mimetype='text/plain')
-    if limit > MAX_JSON_RESULTS:
-        return HttpResponse("too many objects requested", mimetype='text/plain', status=400)
-
-    events = group.event_set.order_by('-id')[:limit]
-
-    Event.objects.bind_nodes(events, 'data')
-
-    return HttpResponse(json.dumps([event.as_dict() for event in events]), mimetype='application/json')
-
-
-@has_access(MEMBER_USER)
-def group_event_details_json(request, team, project, group_id, event_id_or_latest):
+def group_event_details_json(request, organization, project, group_id, event_id_or_latest):
     group = get_object_or_404(Group, pk=group_id, project=project)
 
     if event_id_or_latest == 'latest':
@@ -552,7 +484,7 @@ def group_event_details_json(request, team, project, group_id, event_id_or_lates
 
 @login_required
 @has_access(MEMBER_USER)
-def group_plugin_action(request, team, project, group_id, slug):
+def group_plugin_action(request, organization, project, group_id, slug):
     group = get_object_or_404(Group, pk=group_id, project=project)
 
     try:
@@ -560,12 +492,14 @@ def group_plugin_action(request, team, project, group_id, slug):
     except KeyError:
         raise Http404('Plugin not found')
 
+    GroupMeta.objects.populate_cache([group])
+
     response = plugin.get_view_response(request, group)
     if response:
         return response
 
-    redirect = request.META.get('HTTP_REFERER') or reverse('sentry', kwargs={
-        'team_slug': team.slug,
+    redirect = request.META.get('HTTP_REFERER') or reverse('sentry-stream', kwargs={
+        'organization_slug': organization.slug,
         'project_id': group.project.slug
     })
     return HttpResponseRedirect(redirect)
